@@ -40,11 +40,11 @@ namespace Tomboy
 
 		public const string INSERT_TIMESTAMP_FORMAT = "/apps/tomboy/insert_timestamp/format";
 		
-		// TODO: Convert these into properly localized settings in 0.11.x after freeze is lifted
 		public const string SEARCH_WINDOW_X_POS = "/apps/tomboy/search_window_x_pos";
 		public const string SEARCH_WINDOW_Y_POS = "/apps/tomboy/search_window_y_pos";
 		public const string SEARCH_WINDOW_WIDTH = "/apps/tomboy/search_window_width";
 		public const string SEARCH_WINDOW_HEIGHT = "/apps/tomboy/search_window_height";
+		public const string SEARCH_WINDOW_SPLITTER_POS = "/apps/tomboy/search_window_splitter_pos";
 
 		static IPreferencesClient client;
 
@@ -122,7 +122,6 @@ namespace Tomboy
 
 			case SYNC_CLIENT_ID:
 				return System.Guid.NewGuid ().ToString ();
-				break;
 
 			case SYNC_LOCAL_PATH:
 				return string.Empty;
